Lua_MailItemInfoWindow = class("Lua_MailItemInfoWindow", Lua_Window);
function Lua_MailItemInfoWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_MailItemInfoWindow";
    self.skinName = "MailItemInfoWindow_skin";
    self.showBlackMask = true;
    self.isClickClose = true;
    self.showCloseText = true;
    self.closeTextPosY = -441
end

function Lua_MailItemInfoWindow:buildShowItem()
    self:superCall("buildShowItem");
    
    self.dragContainer = Lua_DragContainer.new(self.content, 530, 220, Lua_AxisDefine.Vertical);
    self.dragContainer:setLocation(0, 168, 0);
    self.dragContainer:addSubContainer(Lua_MailItemInfoDes);

    self.dragList = Lua_DragList.new(self.content, 488, 112, Lua_AxisDefine.Vertical);
    self.dragList:setListCell(Lua_AttachItem, 122, 112, 4);
    self.dragList:setLocation(0, -60, 0);

    self.sureBtn:addClickFuntion(self, self.onButtonClick);

    self:addLuaEvent("UPDATA_MAILITEM_ONE", self, self.updataInfo);
    self:addLuaEvent("UPDATA_MAILITEM_LIST", self, self.updataInfoList);
end

function Lua_MailItemInfoWindow:showWin(param)
    self:superCall("showWin", param);

    Lua_ProxyManager.getProxy("Lua_MailProxy"):sGetSingleMailInfo(param);
end

function Lua_MailItemInfoWindow:updataInfoList(itemList)
    for k,v in ipairs(itemList) do
        if v.mail_id == self.showData then
            self:updataInfo(v);
            break;
        end
    end
end

function Lua_MailItemInfoWindow:updataInfo(data)
    self.data = data;

    self.mailTitleTxt.text = data.title;

    local over_time = data.overtime_tick - os.time();
    self.dragContainer:setChildData(DataCenter.mailData:mailContent(data) .. "_" .. LanUtil.formateStr(128009, tostring(Mathf.Ceil(over_time / 86400))));
    self.dragContainer:updateChildPos();
    self.dragContainer.canDrag = not self.dragContainer.bDragEnd;

    if data.has_attach == 0 then
        self.mailIcon:setAltas("mail_atlas", "ui_yj_icon_02");

        self.sureBtn:setLangValue(128010); -- 删除
        self.sureBtn:setStyle(3);

        self.dragContainer:setContentRect(530, 418);
        self.dragContainer:setLocation(0, 69, 0);
    else
        self.mailIcon:setAltas("mail_atlas", "ui_yj_icon_01");

        self.sureBtn:setLangValue(128011); -- 领取
        self.sureBtn:setStyle(1);

        self.dragContainer:setContentRect(530, 220);
        self.dragContainer:setLocation(0, 168, 0);

        local arr = Array();
        for k,v in ipairs(data.item_list) do
            arr:add(v);
        end
        self.dragList:setArrayData(arr);
        self.dragList:setContentRect(arr:getSize() < 5 and arr:getSize() * 122 or 488, 112);
    end

    self.rewardLabObj:SetActive(data.has_attach ~= 0);
    self.dragList:setEnable(data.has_attach ~= 0);
end

function Lua_MailItemInfoWindow:onButtonClick(go)
    if self.data == nil then
        return;
    end

    if self.data.has_attach == 0 then
        Lua_ProxyManager.getProxy("Lua_MailProxy"):sRemoveMailItem(self.data.mail_id);
        self:hide();
    else
        OperateAlert.showLangValue(128012);
        Lua_ProxyManager.getProxy("Lua_MailProxy"):sReceiveMailItem(self.data.mail_id);
    end 
end

function Lua_MailItemInfoWindow:dispose()
    if self.dragContainer ~= nil then
        self.dragContainer:dispose();
        self.dragContainer = nil;
    end
    if self.dragList ~= nil then
        self.dragList:dispose();
        self.dragList = nil;
    end
    self.data = nil;

    self:superCall("dispose");
end





--------------------------------------------------





Lua_MailItemInfoDes = class("Lua_MailItemInfoDes", Lua_DragContainerItem);
function Lua_MailItemInfoDes:ctor(sub)
    self:superCall("ctor", sub);
end

function Lua_MailItemInfoDes:buildShowItem()
    self:superCall("buildShowItem");

    self.des = UICreate.createLabel(self.content, "", 0, 0, 530, 0, 24);
    self.des.colorStr = Lua_ColorDefine.transColor("846651");
    self.des.pivotValue = 0;
    self.des.anchorValue = 1;
    self.des.verticalOverflowValue = 1;
    self.des.lineSpacing = 1;

    self.mailPeriodTxt = UICreate.createLabel(self.content, "", 0, 0, 530, 0, 24);
    self.mailPeriodTxt.alignmentValue = 5;
    self.mailPeriodTxt.colorStr = Lua_ColorDefine.transColor("9C8472");
    self.mailPeriodTxt.pivotValue = 0;
    self.mailPeriodTxt.anchorValue = 1;
    self.mailPeriodTxt.verticalOverflowValue = 1;
    self.mailPeriodTxt.lineSpacing = 1;
end

function Lua_MailItemInfoDes:setData(data)
    self.data = data;
    if data == nil then
        return;
    end

    local arr = string.split(data, "_");
    self.des.text = arr[1];

    self.mailPeriodTxt.text = arr[2];
    self.mailPeriodTxt:setLocation(self.des.posX, -self.des.height - self.mailPeriodTxt.height);
end

function Lua_MailItemInfoDes:getHeight()
    return self.des.height + self.mailPeriodTxt.height * 2;
end

function Lua_MailItemInfoDes:dispose()
    if self.des ~= nil then
        self.des:dispose();
        self.des = nil;
    end
    if self.mailPeriodTxt ~= nil then
        self.mailPeriodTxt:dispose();
        self.mailPeriodTxt = nil;
    end
    self.data = nil;

    self:superCall("dispose");
end





--------------------------------------------------





Lua_AttachItem = class("Lua_AttachItem", Lua_ListCell);
function Lua_AttachItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_AttachItem:buildShowItem()
    self:superCall("buildShowItem");

    self.ItemIcon = Lua_ItemIcon.new(self.content);
    self.ItemIcon:setLocation(0, 0, 0);
    self.ItemIcon:setCanClick(false);
end

function Lua_AttachItem:setData(data)
    self.data = data;
    if data == nil then
        return;
    end

    local tvo = Lua_ToolVo.createToolVo(data.id, data.amount);
    self.ItemIcon:setData(tvo);
end

function Lua_AttachItem:onPressClick()
    if self.data == nil then
        return;
    end
    DataCenter.packUtil:showItemInfo(self.ItemIcon.data);
end

function Lua_AttachItem:dispose()
    if self.ItemIcon ~= nil then
        self.ItemIcon:dispose();
        self.ItemIcon = nil;
    end
    self.data = nil;

    self:superCall("dispose");
end